@@ -22,7 +22,7 @@
 
 #include <QApplication>
 #include <QDebug>
-#include <QtXml/qdom.h>
+#include <QDomElement>
 #include <QToolTip>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -60,7 +60,7 @@ class FancyPlotterLabel : public QLabel {
         textMargin = 0;
         setLayoutDirection(Qt::LeftToRight); //We do this because we organise the strings ourselves.. is this going to muck it up though for RTL languages?
     }
-    ~FancyPlotterLabel() {
+    ~FancyPlotterLabel() Q_DECL_OVERRIDE {
     }
     void setLabel(const QString &name, const QColor &color) {
         labelName = name;
@@ -69,7 +69,7 @@ class FancyPlotterLabel : public QLabel {
             if(fontMetrics().inFont(QChar(0x25CF)))
                 indicatorSymbol = QChar(0x25CF);
             else
-                indicatorSymbol = '#';
+                indicatorSymbol = QLatin1Char('#');
         }
         changeLabel(color);
 
@@ -77,7 +77,7 @@ class FancyPlotterLabel : public QLabel {
     void setValueText(const QString &value) {
         //value can have multiple strings, separated with the 0x9c character
         valueText = value.split(QChar(0x9c));
-        resizeEvent(NULL);
+        resizeEvent(nullptr);
         update();
     }
     void resizeEvent( QResizeEvent * ) Q_DECL_OVERRIDE {
@@ -116,14 +116,14 @@ class FancyPlotterLabel : public QLabel {
         color = _color;
 
         if ( QApplication::layoutDirection() == Qt::RightToLeft )
-            longHeadingText = QStringLiteral(": ") + labelName + " <font color=\"" + color.name() + "\">" + indicatorSymbol + "</font>";
+            longHeadingText = QStringLiteral(": ") + labelName + QStringLiteral(" <font color=\"") + color.name() + QStringLiteral("\">") + indicatorSymbol + QStringLiteral("</font>");
         else
-            longHeadingText = QStringLiteral("<qt><font color=\"") + color.name() + "\">" + indicatorSymbol + "</font> " + labelName + " :";
-        shortHeadingText = QStringLiteral("<qt><font color=\"") + color.name() + "\">" + indicatorSymbol + "</font>";
-        noHeadingText = QStringLiteral("<qt><font color=\"") + color.name() + "\">";
+            longHeadingText = QStringLiteral("<qt><font color=\"") + color.name() + QStringLiteral("\">") + indicatorSymbol + QStringLiteral("</font> ") + labelName + QStringLiteral(" :");
+        shortHeadingText = QStringLiteral("<qt><font color=\"") + color.name() + QStringLiteral("\">") + indicatorSymbol + QStringLiteral("</font>");
+        noHeadingText = QStringLiteral("<qt><font color=\"") + color.name() + QStringLiteral("\">");
 
-        textMargin = fontMetrics().width('x') + margin()*2 + frameWidth()*2;
-        longHeadingWidth = fontMetrics().boundingRect(labelName + " :" + indicatorSymbol + " x").width() + textMargin;
+        textMargin = fontMetrics().width(QLatin1Char('x')) + margin()*2 + frameWidth()*2;
+        longHeadingWidth = fontMetrics().boundingRect(labelName + QStringLiteral(" :") + indicatorSymbol + QStringLiteral(" x")).width() + textMargin;
         shortHeadingWidth = fontMetrics().boundingRect(indicatorSymbol).width() + textMargin;
         setMinimumWidth(shortHeadingWidth);
         update();
@@ -131,9 +131,9 @@ class FancyPlotterLabel : public QLabel {
   private:
     void setBothText(const QString &heading, const QString & value) {
         if(QApplication::layoutDirection() == Qt::LeftToRight)
-            setText(heading + ' ' + value);
+            setText(heading + QLatin1Char(' ') + value);
         else
-            setText("<qt>" + value + ' ' + heading);
+            setText(QStringLiteral("<qt>") + value + QLatin1Char(' ') + heading);
     }
     int textMargin;
     QString longHeadingText;
@@ -160,7 +160,7 @@ FancyPlotter::FancyPlotter( QWidget* parent,
     mSensorManualMax = mSensorManualMin = 0;
     mUseManualRange = false;
     mNumAnswers = 0;
-    mLabelsWidget = NULL;
+    mLabelsWidget = nullptr;
 
     //The unicode character 0x25CF is a big filled in circle.  We would prefer to use this in the tooltip.
     //However it's maybe possible that the font used to draw the tooltip won't have it.  So we fall back to a 
@@ -169,7 +169,7 @@ FancyPlotter::FancyPlotter( QWidget* parent,
     if(fm.inFont(QChar(0x25CF)))
         mIndicatorSymbol = QChar(0x25CF);
     else
-        mIndicatorSymbol = '#';
+        mIndicatorSymbol = QLatin1Char('#');
 
     QBoxLayout *layout = new QVBoxLayout(this);
     layout->setSpacing(0);
@@ -264,7 +264,7 @@ void FancyPlotter::configureSettings()
     bool hasIntegerRange = true;
     SensorModelEntry::List list;
     for ( int i = 0; i < (int)mBeams; ++i ) {
-        FPSensorProperties *sensor = NULL;
+        FPSensorProperties *sensor = nullptr;
         //find the first sensor for this beam, since one beam can have many sensors
         for ( int j = 0; j < sensors().count(); ++j ) {
             FPSensorProperties *sensor2 = static_cast<FPSensorProperties *>(sensors().at(j));
@@ -299,7 +299,7 @@ void FancyPlotter::settingsFinished()
     applySettings();
     mSettingsDialog->hide();
     mSettingsDialog->deleteLater();
-    mSettingsDialog = 0;
+    mSettingsDialog = nullptr;
 }
 
 void FancyPlotter::applySettings() {
@@ -353,8 +353,8 @@ void FancyPlotter::applySettings() {
 
 void FancyPlotter::resizeEvent( QResizeEvent* )
 {
-    bool showHeading = true;;
-    bool showLabels = true;;
+    bool showHeading = true;
+    bool showLabels = true;
 
     if( height() < mLabelsWidget->sizeHint().height() + mHeading->sizeHint().height() + mPlotter->minimumHeight() )
         showHeading = false;
@@ -428,7 +428,7 @@ bool FancyPlotter::addSensor( const QString &hostName, const QString &name,
 
     /* To differentiate between answers from value requests and info
      * requests we add 100 to the beam index for info requests. */
-    sendRequest( hostName, name + '?', sensors().size() - 1 + 100 );
+    sendRequest( hostName, name + QLatin1Char('?'), sensors().size() - 1 + 100 );
 
     if((int)mBeams == beamId) {
         mPlotter->addBeam( color );
@@ -517,7 +517,7 @@ void FancyPlotter::setTooltip()
             if (sensor->unit() == QLatin1String("%"))
                 lastValue = i18nc("units", "%1%", lastValue);
             else if( !sensor->unit().isEmpty() )
-                lastValue = i18nc("units", QString(QString("%1 ") + sensor->unit()).toUtf8().constData(), lastValue);
+                lastValue = i18nc("units", QString(QStringLiteral("%1 ") + sensor->unit()).toUtf8().constData(), lastValue);
         } else {
             lastValue = i18n("Error");
         }
@@ -536,14 +536,14 @@ void FancyPlotter::setTooltip()
         beamId = sensor->beamId;
 
         if(sensor->isLocalhost()) {
-            tooltip += QStringLiteral( "%1%2 %3 (%4)" ).arg( neednewline  ? "<br>" : "")
-                .arg("<font color=\"" + mPlotter->beamColor( beamId ).name() + "\">"+mIndicatorSymbol+"</font>")
+            tooltip += QStringLiteral( "%1%2 %3 (%4)" ).arg( neednewline  ? QStringLiteral("<br>") : QString())
+                .arg(QStringLiteral("<font color=\"") + mPlotter->beamColor( beamId ).name() + QStringLiteral("\">") + mIndicatorSymbol+ QStringLiteral("</font>"))
                 .arg( i18n(description.toUtf8().constData()) )
                 .arg( lastValue );
 
         } else {
-            tooltip += QStringLiteral( "%1%2 %3:%4 (%5)" ).arg( neednewline ? "<br>" : "" )
-                .arg("<font color=\"" + mPlotter->beamColor( beamId ).name() + "\">"+mIndicatorSymbol+"</font>")
+            tooltip += QStringLiteral( "%1%2 %3:%4 (%5)" ).arg( neednewline ? QStringLiteral("<br>") : QString() )
+                .arg(QStringLiteral("<font color=\"") + mPlotter->beamColor( beamId ).name() + QStringLiteral("\">") + mIndicatorSymbol+ QStringLiteral("</font>"))
                 .arg( sensor->hostName() )
                 .arg( i18n(description.toUtf8().constData()) )
                 .arg( lastValue );
@@ -588,13 +588,13 @@ void FancyPlotter::sendDataToPlotter( )
                         if (sensor->unit() == QLatin1String("%"))
                             lastValue = i18nc("units", "%1%", lastValue);
                         else if( !sensor->unit().isEmpty() )  {
-                            lastValue = i18nc("units", QString("%1 " + sensor->unit()).toUtf8().constData(), lastValue);
+                            lastValue = i18nc("units", QString(QStringLiteral("%1 ") + sensor->unit()).toUtf8().constData(), lastValue);
                         }
                     }
 
                     if(sensor->maxValue != 0 && sensor->unit() != QLatin1String("%")) {
                         //Use a multi length string incase we do not have enough room
-                        lastValue = i18n("%1 of %2" "\xc2\x9c" "%1", lastValue, mPlotter->valueAsString(sensor->maxValue, precision) );
+                        lastValue = i18n("%1 of %2", lastValue, mPlotter->valueAsString(sensor->maxValue, precision) ) + "\xc2\x9c" + lastValue;
                     }
                 } else {
                     lastValue = i18n("Error");
@@ -660,7 +660,7 @@ void FancyPlotter::plotterAxisScaleChanged()
 #endif
         mPlotter->setScaleDownBy(1);
         //translate any others
-        unit = ki18nc("units", QString("%1 " + mUnit).toUtf8().constData());
+        unit = ki18nc("units", QString(QStringLiteral("%1 ") + mUnit).toUtf8().constData());
     }
     mPlotter->setUnit(unit);
     //reconnect
@@ -784,8 +784,8 @@ bool FancyPlotter::restoreSettings( QDomElement &element )
     mPlotter->setStackGraph( element.attribute(QStringLiteral("stacked"), QStringLiteral("0")).toInt());
 
     QString filename = element.attribute( QStringLiteral("svgBackground"));
-    if (!filename.isEmpty() && filename[0] == '/') {
-        filename = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "ksysguard/" + filename);
+    if (!filename.isEmpty() && filename[0] == QLatin1Char('/')) {
+        filename = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("ksysguard/") + filename);
     }
     mPlotter->setSvgBackground( filename );
     if(version >= 1) {
@@ -805,7 +805,7 @@ bool FancyPlotter::restoreSettings( QDomElement &element )
             sensor->hostname = el.attribute( QStringLiteral("hostName") );
             sensor->type = el.attribute( QStringLiteral("sensorType") );
             sensor->summationName = el.attribute(QStringLiteral("summationName"));
-            QStringList colors = el.attribute(QStringLiteral("color")).split(',');
+            QStringList colors = el.attribute(QStringLiteral("color")).split(QLatin1Char(','));
             bool ok;
             foreach(const QString &color, colors) {
                 int c = color.toUInt( &ok, 0 );
